Class: GeoKit::Geocoders::CaGeocoder
- Defined in:
- lib/geo_kit/geocoders.rb
Overview
Geocoder CA geocoder implementation. Requires the GeoKit::Geocoders::GEOCODER_CA variable to contain true or false based upon whether authentication is to occur. Conforms to the interface set by the Geocoder class.
Returns a response like: